@@ -93,12 +93,12 @@ function activateNextPrevTask(anchor, next) {
     tasksModel.requestActivate(target);
 }
 
-function activateTask(index, model, modifiers) {
+function activateTask(index, model, modifiers, task) {
     if (modifiers & Qt.ShiftModifier) {
         tasksModel.requestNewInstance(index);
     } else if (model.IsGroupParent === true) {
         if ((iconsOnly || modifiers == Qt.ControlModifier) && backend.canPresentWindows()) {
-            toolTip.hideToolTip();
+            toolTipArea.hideToolTip();
             tasks.presentWindows(model.LegacyWinIdList);
         } else if (groupDialog.visible) {
             groupDialog.visible = false;
